@@ -3,11 +3,56 @@ import re
 
 import traitlets
 
+from .locations import locations_to_list
+
 
 class InvalidPointException(Exception):
     pass
 
 
+class InvalidWeightException(Exception):
+    pass
+
+
+class LocationArray(traitlets.List):
+    info_text = 'An iterable of locations'
+    default_value = traitlets.Undefined
+
+    def validate(self, obj, value):
+        if value is None:
+            return super(LocationArray, self).validate(obj, value)
+        locations_as_list = locations_to_list(value)
+        for location in locations_as_list:
+            latitude, longitude = location
+            _validate_latitude(latitude)
+            _validate_longitude(longitude)
+        return super(LocationArray, self).validate(obj, locations_as_list)
+
+
+class WeightArray(traitlets.List):
+    info_text = 'An iterable of non-negative weights'
+    default_value = traitlets.Undefined
+
+    def validate(self, obj, value):
+        if value is None:
+            return super(WeightArray, self).validate(obj, value)
+        weights = list(value)
+        for weight in weights:
+            try:
+                weight = float(weight)
+            except (TypeError, ValueError):
+                raise traitlets.TraitError(
+                    '{} is not a valid weight. '
+                    'Weights must be floats'.format(weight)
+                )
+            if weight < 0.0:
+                raise InvalidWeightException(
+                    '{} is not a valid weight. '
+                    'Weights must be non-negative.'.format(weight)
+                )
+        return super(WeightArray, self).validate(obj, weights)
+
+
 class Latitude(traitlets.Float):
     """
     Float representing a latitude
@@ -18,10 +63,8 @@ class Latitude(traitlets.Float):
     default_value = traitlets.Undefined
 
     def validate(self, obj, value):
-        if -90.0 <= value <= 90.0:
-            return value
-        else:
-            self.error(obj, value)
+        _validate_latitude(value)
+        return value
 
 
 class Longitude(traitlets.Float):
@@ -34,10 +77,8 @@ class Longitude(traitlets.Float):
     default_value = traitlets.Undefined
 
     def validate(self, obj, value):
-        if -180.0 <= value <= 180.0:
-            return value
-        else:
-            self.error(obj, value)
+        _validate_longitude(value)
+        return value
 
 
 class Point(traitlets.Tuple):
@@ -172,3 +213,34 @@ class ColorAlpha(traitlets.Union):
 def is_valid_point(pt):
     latitude, longitude = pt
     return (-90.0 <= latitude <= 90.0) and (-180.0 <= longitude <= 180.0)
+
+
+def _validate_latitude(latitude):
+    try:
+        latitude = float(latitude)
+    except (TypeError, ValueError):
+        raise traitlets.TraitError(
+            '{} is not a valid latitude. '
+            'Latitudes must be floats'.format(latitude)
+        )
+    if not (-90.0 <= latitude <= 90.0):
+        raise InvalidPointException(
+            '{} is not a valid latitude. '
+            'Latitudes must lie between -90 and 90.'.format(latitude)
+        )
+
+
+def _validate_longitude(longitude):
+    try:
+        longitude = float(longitude)
+    except (TypeError, ValueError):
+        raise traitlets.TraitError(
+            '{} is not a valid longitude. '
+            'Longitudes must be floats'.format(longitude)
+        )
+    if not (-180.0 <= longitude <= 180.0):
+        raise InvalidPointException(
+            '{} is not a valid longitude. '
+            'Longitudes must lie between '
+            '-180 and 180.'.format(longitude)
+        )
